@@ -64,10 +64,10 @@ function _aws_cdk_aws_ivs_ChannelProps(p) {
         _aws_cdk_aws_ivs_ChannelType(p.type);
     visitedObjects.delete(p);
 }
-function _aws_cdk_aws_ivs_CfnStreamKey(p) {
-}
 function _aws_cdk_aws_ivs_CfnPlaybackKeyPair(p) {
 }
+function _aws_cdk_aws_ivs_CfnStreamKey(p) {
+}
 function _aws_cdk_aws_ivs_Channel(p) {
 }
 function _aws_cdk_aws_ivs_CfnChannel(p) {
@@ -93,5 +93,5 @@ function print(name, deprecationMessage) {
 const visitedObjects = new Set();
 class DeprecationError extends Error {
 }
-module.exports = { print, _aws_cdk_aws_ivs_LatencyMode, _aws_cdk_aws_ivs_ChannelType, _aws_cdk_aws_ivs_PlaybackKeyPairProps, _aws_cdk_aws_ivs_IPlaybackKeyPair, _aws_cdk_aws_ivs_IStreamKey, _aws_cdk_aws_ivs_StreamKeyProps, _aws_cdk_aws_ivs_CfnStreamKeyProps, _aws_cdk_aws_ivs_CfnPlaybackKeyPairProps, _aws_cdk_aws_ivs_IChannel, _aws_cdk_aws_ivs_CfnChannelProps, _aws_cdk_aws_ivs_CfnRecordingConfigurationProps, _aws_cdk_aws_ivs_PlaybackKeyPair, _aws_cdk_aws_ivs_StreamKey, _aws_cdk_aws_ivs_ChannelProps, _aws_cdk_aws_ivs_CfnStreamKey, _aws_cdk_aws_ivs_CfnPlaybackKeyPair, _aws_cdk_aws_ivs_Channel, _aws_cdk_aws_ivs_CfnChannel, _aws_cdk_aws_ivs_CfnRecordingConfiguration, _aws_cdk_aws_ivs_CfnRecordingConfiguration_S3DestinationConfigurationProperty, _aws_cdk_aws_ivs_CfnRecordingConfiguration_DestinationConfigurationProperty };
+module.exports = { print, _aws_cdk_aws_ivs_LatencyMode, _aws_cdk_aws_ivs_ChannelType, _aws_cdk_aws_ivs_PlaybackKeyPairProps, _aws_cdk_aws_ivs_IPlaybackKeyPair, _aws_cdk_aws_ivs_IStreamKey, _aws_cdk_aws_ivs_StreamKeyProps, _aws_cdk_aws_ivs_CfnStreamKeyProps, _aws_cdk_aws_ivs_CfnPlaybackKeyPairProps, _aws_cdk_aws_ivs_IChannel, _aws_cdk_aws_ivs_CfnChannelProps, _aws_cdk_aws_ivs_CfnRecordingConfigurationProps, _aws_cdk_aws_ivs_PlaybackKeyPair, _aws_cdk_aws_ivs_StreamKey, _aws_cdk_aws_ivs_ChannelProps, _aws_cdk_aws_ivs_CfnPlaybackKeyPair, _aws_cdk_aws_ivs_CfnStreamKey, _aws_cdk_aws_ivs_Channel, _aws_cdk_aws_ivs_CfnChannel, _aws_cdk_aws_ivs_CfnRecordingConfiguration, _aws_cdk_aws_ivs_CfnRecordingConfiguration_S3DestinationConfigurationProperty, _aws_cdk_aws_ivs_CfnRecordingConfiguration_DestinationConfigurationProperty };
 module.exports.DeprecationError = DeprecationError;
